# This is a firmware package, so binaries (which are not run on the host)
# in the end package are expected.
%define _binaries_in_noarch_packages_terminate_build   0
%global _firmwarepath  /usr/lib/firmware

%global sof_version 1.6.1
%global sof_commit 47b436af36c18c3b4f409e1d9452aea18e17abc8
%global sof_shortcommit %(c=%{sof_commit}; echo ${c:0:7})

Summary:        Firmware and topology files for Sound Open Firmware project
Name:           alsa-sof-firmware
Version:        %{sof_version}
Release:        %mkrel 1
# See later in the spec for a breakdown of licensing
License:        BSD
Group:          System/Kernel and hardware
URL:            https://github.com/thesofproject/sof-bin
#Source:         https://github.com/thesofproject/sof-bin/archive/%{sof_commit}/sof-bin-%{sof_shortcommit}.tar.gz
Source:		https://github.com/thesofproject/sof-bin/archive/v%{sof_version}.tar.gz
Conflicts:      alsa-firmware <= 1.2.1-6

# noarch, since the package is firmware
BuildArch:      noarch

%description
This package contains the firmware binaries for the Sound Open Firmware project.

%package debug
Requires:       alsa-sof-firmware
Summary:        Debug files for Sound Open Firmware project
License:        BSD

%description debug
This package contains the debug files for the Sound Open Firmware project.


%prep
%autosetup -n sof-bin-%{sof_version}

cd lib/firmware

# we have the version in the package name
mv intel/sof/v%{sof_version}/* intel/sof
rmdir intel/sof/v%{sof_version}

# rename intel signed firmware files
for platform in apl cnl ehl icl tgl; do
  mv intel/sof/intel-signed/sof-$platform-v%{sof_version}.ri intel/sof/intel-signed/sof-$platform.ri
  ln -sf intel-signed/sof-$platform.ri intel/sof/sof-$platform.ri
done

# rename public signed firmware files
for platform in apl cnl icl tgl; do
  mv intel/sof/public-signed/sof-$platform-v%{sof_version}.ri intel/sof/public-signed/sof-$platform.ri
done

# rename unsigned firmware files
for platform in bdw byt cht; do
  mv intel/sof/sof-$platform-v%{sof_version}.ri intel/sof/sof-$platform.ri
done

# rename debug files
for platform in apl bdw byt cht cnl ehl icl tgl; do
  mv intel/sof/sof-$platform-v%{sof_version}.ldc intel/sof/sof-$platform.ldc
done

# add missing symlink
ln -s intel-signed/sof-cnl.ri intel/sof/sof-cml.ri
ln -s intel-signed/sof-cnl.ri intel/sof/sof-cfl.ri

# move topology files
mv intel/sof-tplg-v%{sof_version} intel/sof-tplg

# remove NXP firmware files
rm -rf nxp ../../LICENCE.NXP
rm -rf intel/sof-tplg/sof-imx8*

%build
 
%install
mkdir -p %{buildroot}%{_firmwarepath}
cp -ra lib/firmware/* %{buildroot}%{_firmwarepath}

# gather files and directories
FILEDIR=$(pwd)
pushd %{buildroot}/%{_firmwarepath}
find -P . -name "*.ri" | sed -e '/^.$/d' > $FILEDIR/alsa-sof-firmware.files
#find -P . -name "*.tplg" | sed -e '/^.$/d' >> $FILEDIR/alsa-sof-firmware.files
find -P . -name "*.ldc" | sed -e '/^.$/d' > $FILEDIR/alsa-sof-firmware.debug-files
find -P . -type d | sed -e '/^.$/d' > $FILEDIR/alsa-sof-firmware.dirs
popd

sed -i -e 's:^./::' alsa-sof-firmware.{files,debug-files,dirs}
sed -i -e 's!^!/usr/lib/firmware/!' alsa-sof-firmware.{files,debug-files,dirs}
sed -e 's/^/%%dir /' alsa-sof-firmware.dirs >> alsa-sof-firmware.files

cat alsa-sof-firmware.files
 
%files -f alsa-sof-firmware.files
%license LICENCE*
%doc README*
%dir %{_firmwarepath}

# Licence: 3-clause BSD
# .. for files with suffix .tplg
%{_firmwarepath}/intel/sof-tplg

# Licence: SOF (3-clause BSD plus others)
# .. for files with suffix .ri
%files debug -f alsa-sof-firmware.debug-files

%pretrans -p <lua>
path = "%{_firmwarepath}/intel/sof-tplg"
st = posix.stat(path)
if st and st.type == "link" then
  os.remove(path)
end


%changelog
* Sun Dec 27 2020 tmb <tmb> 1.6.1-1.mga8
+ Revision: 1664053
- update to 1.6.1

* Wed Oct 21 2020 luigiwalser <luigiwalser> 1.6-1.mga8.nonfree
+ Revision: 1637862
- 1.6.0

* Sun May 31 2020 tv <tv> 1.5.0-1.mga8.nonfree
+ Revision: 1589206
- 1.5.0

* Sun May 31 2020 tv <tv> 1.4.2-2.mga8.nonfree
+ Revision: 1589134
- Fix the upgrade (make /usr/lib/firmware/intel/sof-tplg directory again)
- Remove the version from all paths
- Add missing symlink for sof-cfl.ri

* Mon Mar 30 2020 zezinho <zezinho> 1.4.2-1.mga8.nonfree
+ Revision: 1562322
- imported package alsa-sof-firmware

